@@ -13,6 +13,8 @@ from molo.forms.models import (
     MoloFormField,
     MoloFormPage,
     FormsIndexPage,
+    ArticlePageForms,
+    MoloFormSubmission,
     PersonalisableForm,
     PersonalisableFormField
 )
@@ -76,8 +78,9 @@ class TestFormViews(TestCase, MoloTestCaseMixin):
         self.client2 = Client(HTTP_HOST=self.main2.get_site().hostname)
 
     def create_molo_form_page_with_field(
-            self, parent, display_form_directly=False,
-            allow_anonymous_submissions=False, **kwargs):
+        self, parent, display_form_directly=False,
+        allow_anonymous_submissions=False, **kwargs
+    ):
         molo_form_page = create_molo_form_page(
             parent,
             display_form_directly=display_form_directly,
@@ -717,6 +720,103 @@ class TestFormViews(TestCase, MoloTestCaseMixin):
             'id="id_some-hidden-field">'
         )
 
+    def test_article_form_submissions(self):
+        """
+        with an article page
+        """
+        form = create_molo_form_page(
+            self.forms_index,
+            title='test form',
+            display_form_directly=True,
+            save_article_object=True,
+            allow_anonymous_submissions=True,
+        )
+        field = create_molo_form_formfield(form, 'singleline')
+        hidden_field = create_molo_form_formfield(
+            form, 'hidden', label="hidden_field lets check it out")
+        ArticlePageForms.objects.create(page=self.article, form=form)
+
+        url = self.article.get_full_url()
+        article_field = 'name="article_page" value="{}"' \
+            .format(self.article.pk)
+
+        # Get an article with a related form page
+        res = self.client.get(url)
+        self.assertEqual(res.status_code, 200)
+        self.assertIn(bytes(field.label, encoding='utf-8'), res.content)
+        self.assertIn(bytes(article_field, encoding='utf-8'), res.content)
+        self.assertIn(bytes(hidden_field.label, encoding='utf-8'), res.content)
+        self.assertIn(bytes(self.article.title, encoding='utf-8'), res.content)
+
+        url = form.get_full_url()
+        data = {
+            'article_page': self.article.pk,
+            field.clean_name: 'abc'
+        }
+        # Post: Respond to  form related to article
+        res = self.client.post(url, data=data)
+        self.assertEqual(res.status_code, 302)
+        self.assertEqual(
+            res.url,
+            '/forms/test-form/{}/success/'.format(self.article.pk)
+        )
+        self.assertTrue(
+            MoloFormSubmission.objects.filter(
+                article_page=self.article).exists()
+        )
+
+    def test_article_form_result_calculations(self):
+        """
+        with an article page
+        """
+        form = create_molo_form_page(
+            self.forms_index,
+            title='test form',
+            display_form_directly=True,
+            show_results=True,
+            save_article_object=True,
+            allow_anonymous_submissions=True,
+        )
+        article = self.mk_article(self.section, title='article 2')
+        field = MoloFormField.objects.create(
+            page=form, label='a, b or c?', field_type='singleline')
+
+        ArticlePageForms.objects.create(page=article, form=form)
+        ArticlePageForms.objects.create(page=self.article, form=form)
+
+        form_data = {field.clean_name: 'a', 'article_page': article.pk}
+        MoloFormSubmission.objects.create(
+            page=form, article_page=article, form_data=json.dumps(form_data))
+
+        form_data.update({'article_page': self.article.pk})
+
+        success_url = reverse('molo.forms:success_article_form', kwargs={
+            'slug': form.slug, 'article': self.article.pk})
+
+        results = self.client.post(form.get_full_url(), data=form_data)
+        self.assertEqual(results.status_code, 302)
+        self.assertEqual(results.url, success_url)
+
+        results = self.client.get(success_url)
+        self.assertEqual(results.status_code, 200)
+        self.assertTemplateUsed(results, 'forms/molo_form_page_success.html')
+        self.assertIn(
+            '<span>a</span> 1', str(results.content)
+        )
+
+        form.show_results_as_percentage = True
+        form.save()
+
+        results = self.client.get(success_url)
+        self.assertEqual(results.status_code, 200)
+        self.assertTemplateUsed(results, 'forms/molo_form_page_success.html')
+        self.assertIn(
+            '<span>a</span> 100%', str(results.content)
+        )
+        self.assertNotIn(
+            'article_page', str(results.content)
+        )
+
 
 class TestDeleteButtonRemoved(TestCase, MoloTestCaseMixin):
 
